pub(crate) enum ParseStrictness {
Strict,
CTorCompatible,
}Expand description
A degree of strictness with which to parse a Protocols (or one of its components).
Variants
Strict
We should enforce all rules declared in the spec.
CTorCompatible
We should only enforce rules that are also enforced by C tor.