Protocols

Struct Protocols 

pub struct Protocols(/* private fields */);
A set of supported or required subprotocol versions.

This type supports both recognized subprotocols (listed in ProtoKind), and unrecognized subprotocols (stored by name).

To construct an instance, use the FromStr trait:

use tor_protover::Protocols;
let p: Result<Protocols,_> = "Link=1-3 LinkAuth=2-3 Relay=1-2".parse();

Implementation notes

Because the number of distinct Protocols sets at any given time is much smaller than the number of relays, this type is interned in order to save memory and copying time.

This type is an Arc internally; it is cheap to clone.

Implementations

Source

impl Protocols

pub fn new() -> Self

Return a new empty set of protocol versions.

Warning

To the extend possible, avoid using empty lists to represent the capabilities of an unknown target. Instead, if there is a consensus present, use the required-relay-protocols field of the consensus.

pub fn is_empty(&self) -> bool

Return true if this list of protocols is empty.

pub fn supports_known_subver(&self, proto: ProtoKind, ver: u8) -> bool

Check whether a known protocol version is supported.

use tor_protover::*;
let protos: Protocols = "Link=1-3 HSDir=2,4-5".parse().unwrap();

assert!(protos.supports_known_subver(ProtoKind::Link, 2));
assert!(protos.supports_known_subver(ProtoKind::HSDir, 4));
assert!(! protos.supports_known_subver(ProtoKind::HSDir, 3));
assert!(! protos.supports_known_subver(ProtoKind::LinkAuth, 3));
pub fn supports_subver(&self, proto: &str, ver: u8) -> bool

Check whether a protocol version identified by a string is supported.

use tor_protover::*;
let protos: Protocols = "Link=1-3 Foobar=7".parse().unwrap();

assert!(protos.supports_subver("Link", 2));
assert!(protos.supports_subver("Foobar", 7));
assert!(! protos.supports_subver("Link", 5));
assert!(! protos.supports_subver("Foobar", 6));
assert!(! protos.supports_subver("Wombat", 3));
pub fn supports_named_subver(&self, protover: NamedSubver) -> bool

Check whether a protocol version is supported.

use tor_protover::*;
let protos: Protocols = "Link=1-5 Desc=2-4".parse().unwrap();
assert!(protos.supports_named_subver(named::DESC_FAMILY_IDS)); // Desc=4
assert!(! protos.supports_named_subver(named::CONFLUX_BASE)); // Conflux=1
pub fn supports_numbered_subver(&self, protover: NumberedSubver) -> bool

Check whether a numbered subprotocol capability is supported.

use tor_protover::*;
let protos: Protocols = "Link=1-5 Desc=2-4".parse().unwrap();
assert!(protos.supports_numbered_subver(NumberedSubver::new(ProtoKind::Desc, 4)));
assert!(! protos.supports_numbered_subver(NumberedSubver::new(ProtoKind::Conflux, 1)));
pub fn difference(&self, other: &Protocols) -> Protocols

Return a Protocols holding every protocol flag that is present in self but not other.

use tor_protover::*;
let protos: Protocols = "Desc=2-4 Microdesc=1-5".parse().unwrap();
let protos2: Protocols = "Desc=3 Microdesc=3".parse().unwrap();
assert_eq!(protos.difference(&protos2),
           "Desc=2,4 Microdesc=1-2,4-5".parse().unwrap());
pub fn union(&self, other: &Protocols) -> Protocols

Return a Protocols holding every protocol flag that is present in self or other or both.

use tor_protover::*;
let protos: Protocols = "Desc=2-4 Microdesc=1-5".parse().unwrap();
let protos2: Protocols = "Desc=3 Microdesc=10".parse().unwrap();
assert_eq!(protos.union(&protos2),
           "Desc=2-4 Microdesc=1-5,10".parse().unwrap());
pub fn intersection(&self, other: &Protocols) -> Protocols

Return a Protocols holding every protocol flag that is present in both self and other.

use tor_protover::*;
let protos: Protocols = "Desc=2-4 Microdesc=1-5".parse().unwrap();
let protos2: Protocols = "Desc=3 Microdesc=10".parse().unwrap();
assert_eq!(protos.intersection(&protos2),
           "Desc=3".parse().unwrap());