pub(crate) struct ProtocolsInner {
pub(crate) recognized: [u64; 13],
pub(crate) unrecognized: Vec<SubprotocolEntry>,
}Expand description
Inner representation of Protocols.
We make this a separate type so that we can intern it inside an Intern
Fields
recognized: [u64; 13]A mapping from protocols’ integer encodings to bit-vectors.
unrecognized: Vec<SubprotocolEntry>A vector of unrecognized protocol versions, in sorted order.
Every entry in this list has supported != 0.
Implementations
Sourceimpl ProtocolsInner
impl ProtocolsInner
Sourcepub(crate) fn add(
&mut self,
foundmask: &mut u64,
ent: SubprotocolEntry,
strictness: ParseStrictness,
) -> Result<(), ParseError>
pub(crate) fn add( &mut self, foundmask: &mut u64, ent: SubprotocolEntry, strictness: ParseStrictness, ) -> Result<(), ParseError>
Parsing helper: Try to add a new entry ent to this set of protocols.
Uses foundmask, a bit mask saying which recognized protocols
we’ve already found entries for. Returns an error if ent is
for a recognized protocol we’ve already added.
WARNING: This method DOES NOT enforce uniqueness for unrecognized protocols. The caller is responsible for doing that in a way appropriate for the provided strictness level.
Does not preserve sorting order; the caller must call self.unrecognized.sort() before returning.