pub(crate) struct SubprotocolEntry {
pub(crate) proto: Protocol,
pub(crate) supported: u64,
}Expand description
Representation of a set of versions supported by a protocol.
For now, we only use this type for unrecognized protocols.
Fields
proto: ProtocolWhich protocol’s versions does this describe?
supported: u64A bit-vector defining which versions are supported. If bit
(1<<i) is set, then protocol version i is supported.
Implementations
Sourceimpl SubprotocolEntry
A single SubprotocolEntry is parsed from a string of the format
Name=Versions, where Versions is a comma-separated list of
integers or ranges of integers.
impl SubprotocolEntry
A single SubprotocolEntry is parsed from a string of the format Name=Versions, where Versions is a comma-separated list of integers or ranges of integers.
Sourcepub(crate) fn from_str(
s: &str,
strictness: ParseStrictness,
) -> Result<Self, ParseError>
pub(crate) fn from_str( s: &str, strictness: ParseStrictness, ) -> Result<Self, ParseError>
Parse a SubprotocolEntry with a given level of strictness.