pub struct ProtoKind(/* private fields */);Expand description
A recognized subprotocol.
These names are kept in sync with the names used in consensus documents; the values are kept in sync with the values in the cbor document format in the walking onions proposal.
For the full semantics of each subprotocol, see tor-spec.txt.
Implementations