ProtocolsInner

Struct ProtocolsInner 

pub(crate) struct ProtocolsInner {
    pub(crate) recognized: [u64; 13],
    pub(crate) unrecognized: Vec<SubprotocolEntry>,
}
Inner representation of Protocols.

We make this a separate type so that we can intern it inside an Arc.

Fields

recognized: [u64; 13]

A mapping from protocols’ integer encodings to bit-vectors.

unrecognized: Vec<SubprotocolEntry>

A vector of unrecognized protocol versions, in sorted order.

Every entry in this list has supported != 0.

Implementations

Source

impl ProtocolsInner

pub(crate) fn add( &mut self, foundmask: &mut u64, ent: SubprotocolEntry, ) -> Result<(), ParseError>

Parsing helper: Try to add a new entry ent to this set of protocols.

Uses foundmask, a bit mask saying which recognized protocols we’ve already found entries for. Returns an error if ent is for a protocol we’ve already added.

Does not preserve sorting order; the caller must call self.unrecognized.sort() before returning.