pub(crate) struct SubprotocolEntry {
pub(crate) proto: Protocol,
pub(crate) supported: u64,
}Expand description
Representation of a set of versions supported by a protocol.
For now, we only use this type for unrecognized protocols.
Fields
proto: ProtocolWhich protocol’s versions does this describe?
supported: u64A bit-vector defining which versions are supported. If bit
(1<<i) is set, then protocol version i is supported.